@@ -741,13 +741,17 @@ class MapnikSourceConfiguration(SourceConfiguration):
             layers = layers.split(',')
         
         mapfile = self.context.globals.abspath(self.conf['mapfile'])
-        from mapproxy.source.mapnik import MapnikSource
+        
+        if self.conf.get('use_mapnik2', False):
+            from mapproxy.source.mapnik import Mapnik2Source as MapnikSource
+        else:
+            from mapproxy.source.mapnik import MapnikSource
         return MapnikSource(mapfile, layers=layers, image_opts=image_opts,
             coverage=coverage, res_range=res_range, lock=lock)
 
 class TileSourceConfiguration(SourceConfiguration):
     source_type = ('tile',)
-    defaults = {'origin': 'sw', 'grid': 'GLOBAL_MERCATOR'}
+    defaults = {'grid': 'GLOBAL_MERCATOR'}
     
     def source(self, params=None):
         from mapproxy.client.tile import TileClient, TileURLTemplate
@@ -760,18 +764,23 @@ class TileSourceConfiguration(SourceConfiguration):
         if params is None: params = {}
         
         url = self.conf['url']
-        origin = self.conf['origin']
-        if origin not in ('sw', 'nw'):
-            log.error("ignoring origin '%s', only supports sw and nw")
+        
+        origin = self.conf.get('origin')
+
+        if origin is not None:
+            warnings.warn('origin for tile sources is deprecated. '
+            'use grid with correct origin.', FutureWarning)
+        # TODO remove origin with 1.4
+        if origin not in ('sw', 'nw', None):
+            log.error("ignoring origin '%s', only supports sw and nw", origin)
             origin = 'sw'
-            # TODO raise some configuration exception
+        inverse = True if origin == 'nw' else False
         
         http_client, url = self.http_client(url)
         grid = self.context.grids[self.conf['grid']].tile_grid()
         coverage = self.coverage()
         image_opts = self.image_opts()
         
-        inverse = True if origin == 'nw' else False
         format = file_ext(params['format'])
         client = TileClient(TileURLTemplate(url, format=format), http_client=http_client, grid=grid)
         return TiledSource(grid, client, inverse=inverse, coverage=coverage,
@@ -808,7 +817,7 @@ class CacheConfiguration(ConfigurationBase):
         if ('cache_dir' not in self.conf 
             and 'base_dir' not in self.context.globals.conf.get('cache', {})):
             warnings.warn('globals.cache.base_dir not defined. default value '
-            '(../var/cache_data) will be changed with 1.2.0.', FutureWarning)
+            '(../var/cache_data) will be changed with 1.4.0.', FutureWarning)
         return self.context.globals.get_path('cache_dir', self.conf,
             global_key='cache.base_dir')
         
@@ -816,7 +825,6 @@ class CacheConfiguration(ConfigurationBase):
         from mapproxy.cache.file import FileCache
         
         cache_dir = self.cache_dir()
-        grid_conf.tile_grid() #create to resolve `base` in grid_conf.conf
         directory_layout = self.conf.get('cache', {}).get('directory_layout', 'tc')
         suffix = grid_conf.conf['srs'].replace(':', '')
         cache_dir = os.path.join(cache_dir, self.conf['name'] + '_' + suffix)
@@ -843,11 +851,33 @@ class CacheConfiguration(ConfigurationBase):
             mbfile_path = os.path.join(self.cache_dir(), filename)
         return MBTilesCache(mbfile_path)
 
+    def _couchdb_cache(self, grid_conf, file_ext):
+        from mapproxy.cache.couchdb import CouchDBCache, CouchDBMDTemplate
+        
+        cache_dir = self.cache_dir()
+        
+        db_name = self.conf['cache'].get('db_name')
+        if not db_name:
+            suffix = grid_conf.conf['srs'].replace(':', '')
+            db_name = self.conf['name'] + '_' + suffix
+        
+        url = self.conf['cache'].get('url')
+        if not url:
+            url = 'http://127.0.0.1:5984'
+        
+        md_template = CouchDBMDTemplate(self.conf['cache'].get('tile_metadata', {}))
+        tile_id = self.conf['cache'].get('tile_id')
+        
+        return CouchDBCache(url=url, db_name=db_name,
+            lock_dir=cache_dir, file_ext=file_ext, tile_grid=grid_conf.tile_grid(),
+            md_template=md_template, tile_id_template=tile_id)
+
     def _tile_cache(self, grid_conf, file_ext):
         if self.conf.get('disable_storage', False):
             from mapproxy.cache.dummy import DummyCache
             return DummyCache()
         
+        grid_conf.tile_grid() #create to resolve `base` in grid_conf.conf
         cache_type = self.conf.get('cache', {}).get('type', 'file')
         return getattr(self, '_%s_cache' % cache_type)(grid_conf, file_ext)
     
@@ -855,6 +885,8 @@ class CacheConfiguration(ConfigurationBase):
         filters = []
         if 'watermark' in self.conf:
             from mapproxy.tilefilter import create_watermark_filter
+            if self.conf['watermark'].get('color'):
+                self.conf['watermark']['color'] = parse_color(self.conf['watermark']['color'])
             f = create_watermark_filter(self.conf, self.context)
             if f:
                 filters.append(f)
@@ -1077,10 +1109,17 @@ class ServiceConfiguration(ConfigurationBase):
             creator = getattr(self, service_name + '_service', None)
             if not creator:
                 raise ValueError('unknown service: %s' % service_name)
-            if service_name in ('wms', 'wmts'):
-                ows_services.append(creator(service_conf or {}))
-            else:
-                services.append(creator(service_conf or {}))
+            
+            new_services = creator(service_conf or {})
+            # a creator can return a list of services...
+            if not isinstance(new_services, (list, tuple)):
+                new_services = [new_services]
+            
+            for new_service in new_services:
+                if getattr(new_service, 'service', None):
+                    ows_services.append(new_service)
+                else:
+                    services.append(new_service)
         
         if ows_services:
             from mapproxy.service.ows import OWSServer
@@ -1116,12 +1155,26 @@ class ServiceConfiguration(ConfigurationBase):
         return TileServer(layers, md, max_tile_age=max_tile_age)
     
     def wmts_service(self, conf):
-        from mapproxy.service.wmts import WMTSServer
+        from mapproxy.service.wmts import WMTSServer, WMTSRestServer
         
         md = self.context.services.conf.get('wms', {}).get('md', {}).copy()
         md.update(conf.get('md', {}))
         layers = self.tile_layers(conf)
-        return WMTSServer(layers, md)
+        
+        kvp = conf.get('kvp')
+        restful = conf.get('restful')
+        
+        if kvp is None and restful is None:
+            kvp = restful = True
+        
+        services = []
+        if kvp:
+            services.append(WMTSServer(layers, md))
+        if restful:
+            template = conf.get('restful_template')
+            services.append(WMTSRestServer(layers, md, template=template))
+        
+        return services
     
     def wms_service(self, conf):
         from mapproxy.service.wms import WMSServer
@@ -1156,10 +1209,18 @@ class ServiceConfiguration(ConfigurationBase):
         info_types = conf.get('featureinfo_types')
         srs = self.context.globals.get_value('srs', conf, global_key='wms.srs')
         self.context.globals.base_config.wms.srs = srs
+        bbox_srs = conf.get('bbox_srs')
+        
+        max_output_pixels = self.context.globals.get_value('max_output_pixels', conf,
+            global_key='wms.max_output_pixels')
+        if isinstance(max_output_pixels, list):
+            max_output_pixels = max_output_pixels[0] * max_output_pixels[1]
+        
         server = WMSServer(root_layer, md, attribution=attribution,
             image_formats=image_formats, info_types=info_types,
             srs=srs, tile_layers=tile_layers, strict=strict, on_error=on_source_errors,
-            concurrent_layer_renderer=concurrent_layer_renderer)
+            concurrent_layer_renderer=concurrent_layer_renderer,
+            max_output_pixels=max_output_pixels, bbox_srs=bbox_srs)
         
         server.fi_transformers = fi_xslt_transformers(conf, self.context)
         
