@@ -87,7 +87,15 @@ cache_types = {
     },
     'mbtiles': {
         'filename': str()
-    }
+    },
+    'couchdb': {
+        'url': str(),
+        'db_name': str(),
+        'tile_metadata': {
+            anything(): anything()
+        },
+        'tile_id': str(),
+    },
 }
 
 mapproxy_yaml_spec = {
@@ -109,6 +117,7 @@ mapproxy_yaml_spec = {
             'lock_dir': str(),
             'meta_size': [number()],
             'meta_buffer': number(),
+            'max_tile_limit': number(),
             'minimize_meta_requests': bool(),
             'concurrent_tile_creators': int(),
         },
@@ -165,6 +174,7 @@ mapproxy_yaml_spec = {
             'watermark': {
                 'text': basestring,
                 'font_size': number(),
+                'color': one_off(str(), [number()]),
                 'opacity': number(),
                 'spacing': str(),
             },
@@ -175,9 +185,14 @@ mapproxy_yaml_spec = {
         'demo': {},
         'kml': {},
         'tms': {},
-        'wmts': {},
+        'wmts': {
+            'kvp': bool(),
+            'restful': bool(),
+            'restful_template': str(),
+        },
         'wms': {
             'srs': [str()],
+            'bbox_srs': [str()],
             'image_formats': [str()],
             'attribution': {
                 'text': basestring,
@@ -186,7 +201,9 @@ mapproxy_yaml_spec = {
             'featureinfo_xslt': {
                 anything(): str()
             },
-            'source_errors': str(),
+            'on_source_errors': str(),
+            'max_output_pixels': one_off(number(), [number()]),
+            'strict': bool(),
             'md': {
                 'title': basestring,
                 'abstract': basestring,
@@ -255,6 +272,7 @@ mapproxy_yaml_spec = {
                 'transparent': bool(),
                 'image': image_opts,
                 'layers': one_off(str(), [str()]),
+                'use_mapnik2': bool(),
             }),
             'debug': {
             },
